==> jc-tke-metadata-1.2.310-sources.jar: com/xforceplus/ultraman/app/jctke/metadata/dict/EmailSendScene.java <==
package com.xforceplus.ultraman.app.jctke.metadata.dict;

import java.util.stream.Stream;
import com.fasterxml.jackson.annotation.JsonValue;

/**
 * <p>
 * email_send_scene
 * </p>
 *
 * @author ultraman
 * @since 2024-07-19
 */
public enum EmailSendScene {

    REJECT("reject", "即时通知申请人付款单驳回"),
    F47_ERROR("F47Error", "即时通知财务F-47处理失败"),
    M_I_R_O_ERROR("MIROError", "即时通知财务MIRO处理失败"),
    BACK("back", "即时通知分公司发票退回"),
    ISSUE_AN_INVOICE_INFORM("issueAnInvoiceInform", "即时通知供应商开票（本地物料）"),
    INVOICE_NOTICE_BILL("invoiceNoticeBill", "即时通知供应商开票"),
    PAYMENT_SUBMIT_NOTIFY("paymentSubmitNotify", "即时通知分公司审批应付单（安装&本地物料）"),
    F47__RESPONSE__ERROR("F47_Response_Error", "定时通知财务F-47失败清单"),
    F51__RESPONSE__ERROR("F51_Response_Error", "定时通知财务F-51失败清单"),
    F44__RESPONSE__ERROR("F44_Response_Error", "定时通知财务F-44失败清单"),
    M_I_R_O__RESPONSE__ERROR("MIRO_Response_Error", "定时通知财务MIRO失败清单");

    @JsonValue
    private final String code;

    private final String desc;

    public String getCode(){
        return this.code;
    }

    public String getDesc(){
        return this.desc;
    }

    public String code(){
        return this.code;
    }

    public String desc(){
        return this.desc;
    }

    EmailSendScene(String code, String desc) {
        this.code = code;
        this.desc = desc;
    }

    @Override
    public String toString() {
        return this.code;
    }

    public static EmailSendScene fromCode(String code) {
        return Stream.of(EmailSendScene.values())
                .filter(t -> t.code().equals(code))
                .findFirst().orElse(null);
    }
}

==> jc-tke-metadata-1.2.333-sources.jar: com/xforceplus/ultraman/app/jctke/metadata/dict/EmailSendScene.java <==
package com.xforceplus.ultraman.app.jctke.metadata.dict;

import java.util.stream.Stream;
import com.fasterxml.jackson.annotation.JsonValue;

/**
 * <p>
 * email_send_scene
 * </p>
 *
 * @author ultraman
 * @since 2024-07-25
 */
public enum EmailSendScene {

    REJECT("reject", "即时通知申请人付款单驳回"),
    F47_ERROR("F47Error", "即时通知财务F-47处理失败"),
    M_I_R_O_ERROR("MIROError", "即时通知财务MIRO处理失败"),
    BACK("back", "即时通知分公司发票退回"),
    ISSUE_AN_INVOICE_INFORM("issueAnInvoiceInform", "即时通知供应商开票（本地物料）"),
    INVOICE_NOTICE_BILL("invoiceNoticeBill", "即时通知供应商开票"),
    PAYMENT_SUBMIT_NOTIFY("paymentSubmitNotify", "即时通知分公司审批应付单（安装&本地物料）"),
    F47__RESPONSE__ERROR("F47_Response_Error", "定时通知财务F-47失败清单"),
    F51__RESPONSE__ERROR("F51_Response_Error", "定时通知财务F-51失败清单"),
    F44__RESPONSE__ERROR("F44_Response_Error", "定时通知财务F-44失败清单"),
    M_I_R_O__RESPONSE__ERROR("MIRO_Response_Error", "定时通知财务MIRO失败清单"),
    INVOICE_ERROR("invoiceError", "即时通知发票异常提醒");

    @JsonValue
    private final String code;

    private final String desc;

    public String getCode(){
        return this.code;
    }

    public String getDesc(){
        return this.desc;
    }

    public String code(){
        return this.code;
    }

    public String desc(){
        return this.desc;
    }

    EmailSendScene(String code, String desc) {
        this.code = code;
        this.desc = desc;
    }

    @Override
    public String toString() {
        return this.code;
    }

    public static EmailSendScene fromCode(String code) {
        return Stream.of(EmailSendScene.values())
                .filter(t -> t.code().equals(code))
                .findFirst().orElse(null);
    }
}
